@@ -1,4 +1,7 @@
-# coding=utf-8
+"""
+SimpleMonitor alerts via Telegram
+"""
+
 from typing import cast
 
 import requests
@@ -24,16 +27,21 @@ class TelegramAlerter(Alerter):
             str, self.get_config_option("chat_id", required=True, allow_empty=False)
         )
 
+        self.timeout = cast(
+            int, self.get_config_option("timeout", required_type="int", default=5)
+        )
+
         self.support_catchup = True
 
     def send_telegram_notification(self, body: str) -> None:
         """Send a push notification."""
 
-        r = requests.post(
-            "https://api.telegram.org/bot{}/sendMessage".format(self.telegram_token),
+        response = requests.post(
+            f"https://api.telegram.org/bot{self.telegram_token}/sendMessage",
             data={"chat_id": self.telegram_chatid, "text": body},
+            timeout=self.timeout,
         )
-        if not r.status_code == requests.codes.ok:
+        if not response.status_code == requests.codes.ok:
             raise RuntimeError("Unable to send telegram notification")
 
     def send_alert(self, name: str, monitor: Monitor) -> None:
@@ -51,9 +59,7 @@ class TelegramAlerter(Alerter):
             except Exception:
                 self.alerter_logger.exception("Couldn't send push notification")
         else:
-            self.alerter_logger.info("dry_run: would send push notification: %s" % body)
+            self.alerter_logger.info("dry_run: would send push notification: %s", body)
 
     def _describe_action(self) -> str:
-        return "posting messages to {chatid} on Telegram".format(
-            chatid=self.telegram_chatid
-        )
+        return f"posting messages to {self.telegram_chatid} on Telegram"
